@@ -810,7 +810,215 @@ def modeltype_load(modelfile,word,wordslist1,wordslist2):
     loaded_func = load_file_as_function(modelfile)
     return loaded_func(word,wordslist1,wordslist2)
 
-def model_load(modeltype,input, model):
+def nlpm(word,model,words_list1,words_list2,modelname):
+    def rephrase_sentence(sentence, synonyms):
+        # Split the sentence into words
+        words = sentence.split()
+
+        # Loop through each word in the sentence
+        new_words = []
+        for word in words:
+            # If the word has a synonym in the dictionary, replace it with a random synonym from the selected list
+            if word in synonyms:
+                synonym_list = synonyms[word]
+                new_word = random.choice(synonym_list)
+            # Otherwise, keep the original word
+            else:
+                new_word = word
+            new_words.append(new_word)
+
+        # Join the new words into a rephrased sentence
+        return ' '.join(new_words)
+
+    # Define lists of custom synonyms for each word
+    #happy_synonyms = ['glad', 'joyful', 'elated']
+    #angry_synonyms = ['upset', 'mad', 'irate']
+    #run_synonyms = ['jog', 'sprint', 'dash']
+    #big_synonyms = ['large', 'huge', 'enormous']
+    #small_synonyms = ['tiny', 'micro', 'microscopic']
+    #hot_synonyms = ['warm', 'toasty', 'boiling']
+    #good_synonyms = ['great', 'excellent', 'superb']
+    #bad_synonyms = ['terrible', 'awful', 'dreadful']
+    #beautiful_synonyms = ['gorgeous', 'stunning', 'elegant']
+    happy_synonyms = ['glad', 'joyful', 'elated', 'pleased', 'content', 'cheerful', 'ecstatic', 'overjoyed', 'thrilled',
+                      'delighted', 'satisfied']
+    angry_synonyms = ['upset', 'mad', 'irate', 'furious', 'enraged', 'incensed', 'outraged', 'livid', 'exasperated',
+                      'aggravated', 'infuriated']
+    run_synonyms = ['jog', 'sprint', 'dash', 'gallop', 'jogging', 'trot', 'race', 'jogged', 'running', 'sprinted',
+                    'dashing']
+    big_synonyms = ['large', 'huge', 'enormous', 'gigantic', 'massive', 'colossal', 'vast', 'immense', 'monstrous',
+                    'tremendous', 'substantial']
+    small_synonyms = ['tiny', 'minuscule', 'microscopic', 'miniature', 'little', 'diminutive', 'petite', 'pocket-sized',
+                      'dinky', 'wee', 'puny']
+    hot_synonyms = ['warm', 'toasty', 'boiling', 'scorching', 'sweltering', 'blistering', 'roasting', 'sizzling',
+                    'burning', 'fiery', 'heated']
+    good_synonyms = ['great', 'excellent', 'superb', 'wonderful', 'fantastic', 'terrific', 'splendid', 'amazing',
+                     'marvelous', 'outstanding', 'exceptional']
+    bad_synonyms = ['terrible', 'awful', 'dreadful', 'horrible', 'atrocious', 'abysmal', 'miserable', 'lousy', 'poor',
+                    'unsatisfactory', 'inferior']
+    beautiful_synonyms = ['gorgeous', 'stunning', 'elegant', 'lovely', 'pretty', 'charming', 'attractive', 'alluring','fascinating', 'exquisite', 'radiant']
+    algorithm_synonyms = ['procedure', 'method', 'computation', 'logic', 'program', 'calculation', 'formula', 'process','heuristic', 'routine', 'rule']
+    protocol_synonyms = ['guideline', 'standard', 'convention', 'procedure', 'practice', 'code', 'regulation', 'policy', 'instruction', 'custom', 'norm']
+    encryption_synonyms = ['encoding', 'ciphering', 'scrambling', 'codification', 'obfuscation', 'concealment', 'secret writing', 'security', 'protection', 'cryptography']
+    decryption_synonyms = ['decoding', 'deciphering', 'unscrambling', 'decodification', 'clarification','disentanglement', 'solving', 'decipherment', 'solution', 'decrypting']
+    debugging_synonyms = ['troubleshooting', 'problem-solving', 'diagnosis', 'debug', 'de-bugging', 'fault-finding','bug-hunting', 'investigation', 'testing', 'maintenance']
+    automation_synonyms = ['mechanization', 'computerization', 'robotics', 'industrialization', 'modernization','efficiency', 'streamlining', 'optimization', 'autonomation', 'artificial intelligence']
+    virtualization_synonyms = ['emulation', 'simulation', 'abstraction', 'virtual reality', 'virtualisation']
+    hope = ['optimism', 'aspiration', 'confidence']
+    despair=[ 'hopelessness', 'discouragement', 'resignation']
+    envy=  ['jealousy', 'covetousness', 'resentment']
+    surprise = [ 'astonishment', 'amazement', 'shock']
+    disgust= [ 'revulsion', 'repugnance', 'loathing']
+    curiosity= [ 'inquisitiveness', 'fascination', 'exploration']
+    compassion= [ 'empathy', 'kindness', 'sympathy']
+    aggression= [ 'hostility', 'violence', 'belligerence']
+    trust= [ 'believe', 'faith']
+    doubt= [ 'uncertainty', 'skepticism', 'hesitation']
+    # Combine the synonym lists into a dictionary
+    fast = ['quick', 'speedy', 'swift', 'rapid', 'expeditious']
+    slow = ['leisurely', 'unhurried', 'gradual', 'plodding', 'sluggish']
+    loud= ['noisy', 'boisterous', 'raucous', 'clamorous', 'vociferous']
+    quiet = ['silent', 'peaceful', 'serene', 'tranquil', 'calm']
+    rich = ['wealthy', 'affluent', 'prosperous', 'well-off', 'loaded']
+    poor = ['impoverished', 'destitute', 'needy', 'broke', 'penniless']
+    old = ['ancient', 'elderly', 'senior', 'venerable', 'aged']
+    young = ['youthful', 'juvenile', 'adolescent', 'teenage', 'inexperienced']
+    tall = ['high', 'towering', 'lofty', 'elevated', 'statuesque']
+    short = ['brief', 'concise', 'succinct', 'abridged', 'curtailed']
+    wide = ['broad', 'spacious', 'vast', 'extensive', 'expansive']
+    narrow = ['cramped', 'confined', 'tight', 'limited', 'constricted']
+    sadness= [ 'dejected', 'miserable', 'crestfallen']
+    fear= [' scared', 'terrified', 'panicky']
+    excitement= [ 'thrilled', 'ecstatic', 'pumped']
+    confusion= [ 'puzzled', 'bewildered', 'perplexed']
+    hate =['despise', 'detest', 'loathe']
+    tiredness= [ 'exhausted', 'fatigued', 'weary']
+    hunger= [ 'famished', 'ravenous', 'starving']
+    thirst= [ 'parched', 'dehydrated', 'thirsty']
+    sight= [ 'glimpse', 'glance', 'view']
+    sound= [ 'noise', 'din', 'racket']
+    smell= [ 'fragrance', 'aroma', 'scent']
+    touch= [ 'feel', 'grasp', 'hold']
+    taste= [ 'flavor', 'savor', 'relish']
+    testing = ['verification', 'validation', 'quality assurance', 'trials', 'experimentation', 'assessment', 'inspection', 'checking', 'evaluation', 'analysis']
+    database = ['data repository', 'information system', 'data storage', 'database management system', 'DBMS','data warehouse', 'data lake', 'data center']
+    networking = ['communication', 'interconnectivity', 'inter-networking', 'telecommunications', 'internet','intranet', 'LAN', 'WAN', 'routing', 'switching']
+    security = ['protection', 'safety', 'defense', 'safeguarding', 'fortification', 'guarding', 'prevention','security measures', 'risk management']
+    cloud = ['cloud computing', 'cloud services', 'cloud storage', 'cloud-based', 'cloud infrastructure', 'cloud platform', 'cloud computing technology']
+    machine_learning = ['ML', 'artificial intelligence', 'AI', 'neural networks', 'deep learning', 'supervised learning', 'unsupervised learning', 'reinforcement learning']
+    data_science = ['big data', 'data analytics', 'data mining', 'machine learning', 'artificial intelligence','statistics', 'visualization', 'data modeling']
+    web_development = ['web design', 'front-end development', 'back-end development', 'full-stack development','website creation', 'web application development']
+    mobile_development = ['mobile app development', 'iOS app development', 'Android app development','cross-platform development', 'native app development']
+    UI = ['user interface', 'UI design', 'interface design', 'user experience', 'UX design','graphical user interface', 'GUI']
+    UX = ['user experience', 'UX design', 'user-centered design', 'interaction design', 'user interface','UI design']
+    AI = ['artificial intelligence', 'machine intelligence', 'automation', 'robotics', 'expert system', 'neural network', 'deep learning', 'computer intelligence', 'cognitive computing']
+    data = ['information', 'facts', 'statistics', 'figures', 'details', 'records', 'data points', 'metrics', 'intelligence']
+    network = ['networking', 'interconnectivity', 'communication', 'connectivity', 'links', 'interoperability','data exchange', 'collaboration']
+    software = ['program', 'application', 'code', 'app', 'script', 'software package', 'system', 'platform', 'suite', 'tool']
+    hardware = ['computer equipment', 'machinery', 'devices', 'apparatus', 'gear', 'tools', 'instruments', 'components', 'peripherals', 'electronics']
+    ugly = ['unattractive', 'unsightly', 'repulsive', 'hideous', 'grotesque', 'disgusting', 'unappealing','deformed', 'monstrous', 'foul', 'vile']
+    happy2 = ['blissful', 'upbeat', 'jubilant', 'gleeful', 'merry', 'sanguine', 'exultant', 'contented', 'gratified', 'pleasurable', 'thriving']
+    sad = ['miserable', 'sorrowful', 'downcast', 'heartbroken', 'despondent', 'dejected', 'disheartened', 'blue', 'unhappy', 'gloomy', 'melancholy']
+    laugh = ['giggle', 'chuckle', 'snicker', 'cackle', 'roar', 'snort', 'chortle', 'laughing', 'guffaw','hearty', 'hilarious']
+    cry = ['weep', 'sob', 'whimper', 'sniffle', 'blubber', 'tear', 'wail', 'bawl', 'lament', 'mourn', 'sorrow']
+    synonyms = {
+        'giggle':laugh,
+        'ugly':ugly,
+        'sad':sad,
+        'laugh':laugh,
+        'cry':cry,
+        'ai':AI,
+        'data':data,
+        'network':network,
+        'software':software,
+        'hardware':hardware,
+        'security':security,
+        'cloud':cloud,
+        'machine learning':machine_learning,
+        'data science':data_science,
+        'web development':web_development,
+        'mobile development':mobile_development,
+        'ui': UI,
+        'ux':UX,
+        'testing':testing,
+        'database':database,
+        'tiredness':tiredness,
+        'networking':networking,
+        'hunger':hunger,
+        'thirst':thirst,
+        'sight':sight,
+        'sound':sound,
+        'smell':smell,
+        'touch':touch,
+        'sadness':sadness,
+        'taste':taste,
+        'fear':fear,
+        'excitement':excitement,
+        'confusion':confusion,
+        'hate':hate,
+        'fast':fast,
+        'slow':slow,
+        'loud':loud,
+        'quiet':quiet,
+        'rich':rich,
+        'poor':poor,
+        'old':old,
+        'young':young,
+        'tall':tall,
+        'short':short,
+        'wide':wide,
+        'narrow':narrow,
+        'despair':despair,
+        'envy':envy,
+        'surprise':surprise,
+        'disgust':disgust,
+        'curiosity':curiosity,
+        'compassion':compassion,
+        'aggression':aggression,
+        'trust':trust,
+        'doubt':doubt,
+        'happy': happy_synonyms,
+        'angry': angry_synonyms,
+        'run': run_synonyms,
+        'big': big_synonyms,
+        'small': small_synonyms,
+        'hot': hot_synonyms,
+        'good': good_synonyms,
+        'bad': bad_synonyms,
+        'beautiful': beautiful_synonyms,
+        'algorithm':algorithm_synonyms,
+        'protocol':protocol_synonyms,
+        'encryption':encryption_synonyms,
+        'decryption':decryption_synonyms,
+        'debug':debugging_synonyms,
+        'debugging':debugging_synonyms,
+        'automation':automation_synonyms,
+        'automate':automation_synonyms,
+        'virtualization':virtualization_synonyms,
+        'glad':happy_synonyms,
+        'joyful':happy_synonyms,
+        'cheerful':happy_synonyms,
+        'mad':angry_synonyms,
+        'upset':angry_synonyms,
+        'warm':hot_synonyms,
+        'toasty':hot_synonyms,
+        'awful':bad_synonyms,
+        'terrible':bad_synonyms,
+        'horrible':bad_synonyms,
+        'great':good_synonyms,
+        'excellent':good_synonyms,
+        'nice':good_synonyms,
+        'wonderful':good_synonyms,
+        'superb':good_synonyms,
+        'fantastic':good_synonyms,
+        'hope':hope
+    }
+    def run(modelname,word,model):
+        x = model_load(modelname,word,model)
+        output = rephrase_sentence(x, synonyms)
+        return output
+    return run(modelname,word,model)
+def model_load(modeltype,input, model,modelname):
     global words_list1
     global words_list2
     global model_name
@@ -838,6 +1046,8 @@ def model_load(modeltype,input, model):
         return codewriter("php", input, model)
     elif modeltype == "jswriter":
         return codewriter("js", input, model)
+    elif modeltype == "nlpm":
+        return nlpm(input,model,words_list1,words_list2,modelname)
     else:
         return modeltype_load(modeltype,input,words_list1,words_list2)
 
