@@ -1,9 +1,5 @@
 def find_word_replace_sentence(list1, list2, sentence,prompt):
-    """
-    This function takes in two lists and a sentence, and replaces any instance of "[mask]"
-    in the sentence with the word from list2 at the same index as the word in list1 that matches
-    the given prompt. It then returns the modified sentence.
-    """
+
     # Find the index of the first word in list1 that matches the given prompt
     for i, word in enumerate(list1):
         if word in prompt:
